# Lithium Cobalt Oxide positive electrode parameters

Parameters for a lithium Cobalt Oxide positive electrode, from the paper

> Marquis, S. G., Sulzer, V.,  Timms, R.,  Please, C. P.,  &  Chapman, S. J. (2019). “An  asymptotic derivation of a single particle model with electrolyte”. [Journal of The Electrochemical Society](https://doi.org/10.1149/2.0341915jes), 166(15), A3693-A3706. 

and references therein.
